summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h
diff options
context:
space:
mode:
authormarina <marina@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-06-26 19:59:44 +0000
committermarina <marina@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-06-26 19:59:44 +0000
commit304f03da7473ba7b7816bf16bbbf6dc5f5da370e (patch)
tree9cf40b24285d8e776002e89c7daf4bf02e44403a /TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h
parent77cbebea39ebff1e0a01b4cdeb130053d7cc18c0 (diff)
downloadATCD-304f03da7473ba7b7816bf16bbbf6dc5f5da370e.tar.gz
ChangeLogTag:Sat Jun 26 14:23:25 1999 Marina Spivak
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h b/TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h
index 31bc78138d1..8e12d9d095b 100644
--- a/TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h
+++ b/TAO/orbsvcs/orbsvcs/Naming/Persistent_Naming_Context.h
@@ -26,13 +26,13 @@ class TAO_ORBSVCS_Export TAO_Persistent_Bindings_Map : public TAO_Bindings_Map
// name to object bindings in a Naming Context.
//
// = DESCRIPTION
// Wrapper on top of ACE_Shared_Hash_Map (which is a wrapper
// around ACE_Hash_Map_Manager). Uses ACE_Allocator (allocating
// from persistent storage) to make bindings persistent and
// supports TAO_Bindings_Map interface. Used by TAO_Persistent_Naming_Context.
public:
- typedef ACE_Shared_Hash_Map<TAO_Persistent_ExtId, TAO_Persistent_IntId> HASH_MAP;
+ typedef ACE_Hash_Map_With_Allocator<TAO_Persistent_ExtId, TAO_Persistent_IntId> HASH_MAP;
// Underlying data structure - typedef for ease of use.
// = Initialization and termination methods.
@@ -26,13 +26,13 @@ class TAO_ORBSVCS_Export TAO_Persistent_Bindings_Map : public TAO_Bindings_Map
//
// = DESCRIPTION
- // Wrapper on top of ACE_Shared_Hash_Map (which is a wrapper
+ // Wrapper on top of ACE_Hash_Map_With_Allocator (which is a wrapper
// around ACE_Hash_Map_Manager). Uses ACE_Allocator (allocating
// from persistent storage) to make bindings persistent and